"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActionService = void 0;
const axios_instance_1 = require("../../axios-instance");
class ActionService {
    /**
     * List all of the actions that have been executed on the current account.
     * Limited to 25 actions per page unless otherwise specified.
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const actions = await client.actions.getAllActions();
     * // Paginate actions, 10 per page, starting on page 1
     * actions = await client.actions.getAllActions(10, 1);
     * ```
     */
    getAllActions(perPage, page) {
        page = page ? page : 1;
        perPage = perPage ? perPage : 25;
        return axios_instance_1.instance
            .get('/actions', {
            params: {
                page,
                per_page: perPage
            }
        })
            .then(response => response.data.actions);
    }
    /**
     * Get an existing account action based on the provided ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.actions.getExistingAction('specific-action-id');
     * ```
     */
    getExistingAction(id) {
        return axios_instance_1.instance
            .get(`/actions/${id}`)
            .then(response => response.data.action);
    }
}
exports.ActionService = ActionService;
//# sourceMappingURL=actions.service.js.map