import { Balance } from '../../models/balance';
import { BillingHistory } from '../../models/billing-history';
export declare class BillingHistoryService {
    /**
     * Retrieve the balances on a customer's account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const balance = await client.billingHistory.getMyBalance();
     * ```
     */
    getMyBalance(): Promise<Balance>;
    /**
     * Retrieve a list of all billing history entries
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const billingHistory = await client.billingHistory.getMyBillingHistory();
     * ```
     */
    getMyBillingHistory(): Promise<BillingHistory[]>;
}
