"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BillingHistoryService = void 0;
const axios_instance_1 = require("../../axios-instance");
class BillingHistoryService {
    /**
     * Retrieve the balances on a customer's account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const balance = await client.billingHistory.getMyBalance();
     * ```
     */
    getMyBalance() {
        return axios_instance_1.instance
            .get('/customers/my/balance')
            .then(response => response.data);
    }
    /**
     * Retrieve a list of all billing history entries
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const billingHistory = await client.billingHistory.getMyBillingHistory();
     * ```
     */
    getMyBillingHistory() {
        return axios_instance_1.instance
            .get('/customers/my/billing_history')
            .then(response => response.data.billing_history);
    }
}
exports.BillingHistoryService = BillingHistoryService;
//# sourceMappingURL=billing-history.service.js.map