import { Certificate, CertificateRequest } from '../../models/certificate';
export declare class CertificateService {
    /**
     * Upload a new SSL Certificate
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   name: 'web-cert-01',
     *   private_key: '-----BEGIN PRIVATE KEY-----...',
     *   leaf_certificate: '-----BEGIN CERTIFICATE-----...',
     *   certificate_chain: '-----BEGIN CERTIFICATE-----...'
     * };
     * const cert = await client.certificates.createCertificate(request);
     * ```
     */
    createCertificate(certificateRequest: CertificateRequest): Promise<Certificate>;
    /**
     * Get information about an existing SSL Certificate
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const cert = await client.certificates.getExistingCertificate('cert-id');
     * ```
     */
    getExistingCertificate(certificateId: string): Promise<Certificate>;
    /**
     * Get information about all SSL Certificates on your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const certs = await client.certificates.getAllCertificates();
     * ```
     */
    getAllCertificates(): Promise<Certificate[]>;
    /**
     * Delete a specific SSL Certificate from the provided ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.certificates.deleteCertificate('cert-id');
     * ```
     */
    deleteCertificate(certificateId: string): Promise<void>;
}
