import { Domain, DomainRequest } from '../../models/domain';
export declare class DomainService {
    /**
     * Get a list of all the domains on your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const domains = await client.domains.getAllDomains();
     * ```
     */
    getAllDomains(): Promise<Domain[]>;
    /**
     * Create a new domain on your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const request = {
     *   name: 'example.com',
     *   ip_address: '1.2.3.4'
     * };
     * const domain = await client.domains.createDomain(request);
     * ```
     */
    createDomain(domainRequest: DomainRequest): Promise<Domain>;
    /**
     * Get information about a specific domain
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const domain = await client.domains.getExistingDomain('example.com');
     * ```
     */
    getExistingDomain(domainName: string): Promise<Domain>;
    /**
     * Delete a specific domain from your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.domains.deleteDomain('example.com');
     * ```
     */
    deleteDomain(domainName: string): Promise<void>;
}
