import { Action } from '../../models/action';
export declare class FloatingIPActionService {
    /**
     * Assign an existing Floating IP to a Droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.floatingIPActions
     *    .assignFloatingIPToDroplet('1.2.3.4', 'droplet-id');
     * ```
     */
    assignFloatingIPToDroplet(floatingIPAddress: string, dropletId: string): Promise<Action>;
    /**
     * Unassign an existing Floating IP
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.floatingIPActions
     *    .unassignFloatingIP('1.2.3.4');
     * ```
     */
    unassignFloatingIP(floatingIPAddress: string): Promise<Action>;
    /**
     * Retrieve all actions that have been executed on a Floating IP
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const actions = await client.floatingIPActions
     *    .getAllFloatingIPActions('1.2.3.4');
     * ```
     */
    getAllFloatingIPActions(floatingIPAddress: string): Promise<Action[]>;
    /**
     * Retrieve the status of a Floating IP action
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.floatingIPActions
     *    .getExistingFloatingIPAction('1.2.3.4', 'action-id');
     * ```
     */
    getExistingFloatingIPAction(floatingIPAddress: string, actionId: string): Promise<Action>;
}
