import { FloatingIP } from '../../models/floating-ip';
export declare class FloatingIPService {
    /**
     * List all of the Floating IPs available on your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const floatingIPs = await client.floatingIPs.getAllFloatingIPs();
     * ```
     */
    getAllFloatingIPs(): Promise<FloatingIP>;
    /**
     * Create a new Floating IP assigned to a Droplet
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const floatingIP =
     *    await client.floatingIPs.createFloatingIPForDroplet('droplet-id');
     * ```
     */
    createFloatingIPForDroplet(dropletId: string): Promise<FloatingIP>;
    /**
     * Create a Floating IP reserved to a Region
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const floatingIP =
     *    await client.floatingIPs.createFloatingIPForRegion('nyc3');
     * ```
     */
    createFloatingIPForRegion(region: string): Promise<FloatingIP>;
    /**
     * Show information about an existing Floating IP
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const floatingIP =
     *    await client.floatingIPs.getExistingFloatingIP('1.2.3.4');
     * ```
     */
    getExistingFloatingIP(floatingIPAddress: string): Promise<FloatingIP>;
    /**
     * Delete an existing Floating IP and remove it from your account
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.floatingIPs.deleteFloatingIP('1.2.3.4');
     * ```
     */
    deleteFloatingIP(floatingIPAddress: string): Promise<void>;
}
