import { Action } from '../../models/action';
export declare class ImageActionService {
    /**
     * Transfer an image to another region
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.imageActions.transferImage('image-id', 'nyc1');
     * ```
     */
    transferImage(imageId: number, region: string): Promise<Action>;
    /**
     * Convert an image (a backup for example) to a snapshot
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.imageActions.convertImageToSnapshot('image-id');
     * ```
     */
    convertImageToSnapshot(imageId: number): Promise<Action>;
    /**
     * Retrieve the status of an image action
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.imageActions.getExistingImageAction('image-id', 'action-id');
     * ```
     */
    getExistingImageAction(imageId: number, actionId: number): Promise<Action>;
}
