"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImageActionService = void 0;
const axios_instance_1 = require("../../axios-instance");
class ImageActionService {
    /**
     * Transfer an image to another region
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.imageActions.transferImage('image-id', 'nyc1');
     * ```
     */
    transferImage(imageId, region) {
        const request = {
            region,
            type: 'transfer'
        };
        return axios_instance_1.instance
            .post(`/images/${imageId}/actions`, request)
            .then(response => response.data.action);
    }
    /**
     * Convert an image (a backup for example) to a snapshot
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.imageActions.convertImageToSnapshot('image-id');
     * ```
     */
    convertImageToSnapshot(imageId) {
        const request = {
            type: 'convert'
        };
        return axios_instance_1.instance
            .post(`/images/${imageId}/actions`, request)
            .then(response => response.data.action);
    }
    /**
     * Retrieve the status of an image action
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const action = await client.imageActions.getExistingImageAction('image-id', 'action-id');
     * ```
     */
    getExistingImageAction(imageId, actionId) {
        return axios_instance_1.instance
            .get(`/images/${imageId}/actions/${actionId}`)
            .then(response => response.data.action);
    }
}
exports.ImageActionService = ImageActionService;
//# sourceMappingURL=image-actions.service.js.map