import { Snapshot } from '../../models/snapshot';
export declare type SnapshotType = 'all' | 'droplet' | 'volume';
export declare class SnapshotService {
    /**
     * Get all snapshots on the account.
     * Optionally provide a resource type to filter snapshots.
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * // Get all snapshots
     * const snapshots = await client.snapshots.getSnapshots();
     * // Get all droplet snapshots
     * snapshots = await client.snapshots.getSnapshots('droplet');
     * // Get all volume snapshots
     * snapshots = await client.snapshots.getSnapshots('volume');
     * ```
     */
    getSnapshots(resourceType?: SnapshotType): Promise<Snapshot[]>;
    /**
     * Get a specific existing snapshot by ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * const snapshot = await client.snapshots.getSnapshotById('snapshot-id');
     * ```
     */
    getSnapshotById(snapshotId: string): Promise<Snapshot>;
    /**
     * Delete a specific snapshot by ID
     *
     * ### Example
     * ```js
     * import { DigitalOcean } from 'digitalocean-js';
     *
     * const client = new DigitalOcean('your-api-key');
     * await client.snapshots.deleteSnapshot('snapshot-id');
     * ```
     */
    deleteSnapshot(snapshotId: string): Promise<void>;
}
